import { ARecord, IHostedZone, RecordTarget } from "aws-cdk-lib/aws-route53";
import { Construct } from "constructs";
import { WeightedARecord } from "./weighted-a-record";
import { LatencyARecord } from "./latency-a-record";
import { WeightedLatencyARecord } from "./weighted-latency-a-record";
import { Certificate } from "aws-cdk-lib/aws-certificatemanager";
/**
 * Properties for DomainName
 */
export interface DomainNameProps {
    /**
     * Domain name prefix.
     *
     * @default empty string
     */
    readonly prefix?: string;
    /**
     * Zone for the domain nane.
     */
    readonly zone: string | IHostedZone;
    /**
     * Flag to mark zone as private.
     *
     * @default false
     */
    readonly privateZone?: boolean;
    /**
     * VPC the zone belongs to.
     *
     * @default undefined
     */
    readonly vpcId?: string;
}
/**
 * ACM certificate options
 */
export interface CertificateOptions {
    /**
     * The identifier to use.
     *
     * @default ${this.toIdentifier()}-cert
     */
    readonly id?: string;
    /**
     * Alternative domain names on the certificate.
     */
    readonly subjectAlternativeNames?: string[];
}
/**
 * Utility class for holding domain name information and
 * doing useful things with it.
 */
export declare class DomainName {
    protected readonly prefix: string;
    protected readonly zone: string;
    protected hostedZone?: IHostedZone;
    protected readonly privateZone: boolean;
    protected readonly vpcId?: string;
    /**
     * Creates a new DomainName.
     *
     * @param props the properties of the domain name
     */
    constructor(props: DomainNameProps);
    /**
     * Returns the prefix for this domain name.
     */
    getPrefix(): string;
    /**
     * Returns true if the zone is private. False if otherwise.
     */
    inPrivateZone(): boolean;
    /**
     * Returns the vpc ID for this zone or undefined if one does not exist
     */
    getVpcId(): string | undefined;
    /**
     * Returns true if the props match the domain name. False if otherwise.
     *
     * @param props the props to compare
     */
    propsMatch(props: DomainNameProps): boolean;
    /**
     * Returns the string version of this domain name.
     */
    toString(): string;
    /**
     * Returns a friendly identifier for this domain name.
     */
    toIdentifier(): string;
    /**
     * Returns the zone associated with this domain name.
     */
    getZone(): string;
    /**
     * Returns the route53 hosted zone associated with this domain name.
     * This method is safe to call repeatedly, the lookup will only be done once.
     *
     * @param scope the scope to use if a lookup is required
     * @param id an optional ID if a lookup is required; one is generated if not provided
     */
    getHostedZone(scope: Construct, id?: string): IHostedZone;
    /**
     * Creates a Route53 ARecord for this domain name.
     *
     * @param scope the scope to create the record in
     * @param target the target of the record
     * @param id the optional id for the record; if not provided, one is generated
     */
    createARecord(scope: Construct, target: RecordTarget, id?: string): ARecord;
    /**
     * Creates a weighted Route53 record for this domain name.
     *
     * @param scope the scope to create the record in
     * @param target the target of the record
     * @param weight the initial weight; defaults to 0
     */
    createWeightedARecord(scope: Construct, target: RecordTarget, weight?: number): WeightedARecord;
    /**
     * Creates a latency Route53 record for this domain name.
     *
     * @param scope the scope to create the record in
     * @param target the target of the record
     */
    createLatencyARecord(scope: Construct, target: RecordTarget): LatencyARecord;
    /**
     * Creates a weighted latency Route53 record for this domain name.
     *
     * @param scope the scope to create the record in
     * @param target the target of the record
     * @param weight the initial weight; defaults to 0
     */
    createWeightedLatencyARecord(scope: Construct, target: RecordTarget, weight?: number): WeightedLatencyARecord;
    /**
     * Creates an ACM certificate for the domain name.
     *
     * @param scope the scope to create the record in
     * @param opts additional options
     */
    createCertificate(scope: Construct, opts?: CertificateOptions): Certificate;
    /**
     * Converts an array of DomainNameProps to DomainName. This function will return an empty array
     * if domainNameProps is undefined.
     *
     * @param domainNameProps the DomainNameProps objects to convert
     */
    static fromProps(domainNameProps?: DomainNameProps[]): DomainName[];
    /**
     * Converts an array of DomainName objects to an array of strings. This function will return an
     * empty array if domainNames is undefined.
     *
     * @param domainNames the DomainName objects to convert
     */
    static toStrings(domainNames?: DomainName[]): string[];
    /**
     * Converts an array of DomainNameProps to an array of strings. This function will
     * return an empty array if domainNameProps is undefined.
     *
     * @param domainNameProps the DomainNameProps objects to convert
     */
    static toStringsFromProps(domainNameProps?: DomainNameProps[]): string[];
    /**
     * Converts an array of DomainName objects to a map where the key is the domain name string and the value
     * is an IHostedZone. This method will return an empty map if domainNames is undefined. This function
     * is useful when used in conjunction with functions like CertificateValidation.fromDnsMultiZone.
     *
     * @param scope the scope used if a zone lookup is required
     * @param domainNames the DomainName objects to convert
     */
    static toZoneMap(scope: Construct, domainNames?: DomainName[]): {
        [domainName: string]: IHostedZone;
    };
    /**
     * Converts an array of DomainNameProps objects to a map where the key is the domain name string and the
     * value is an IHostedZone. This method will return an empty map if domainNameProps is undefined. This
     * function is useful when used in conjunction with functions like CertificateValidation.fromDnsMultiZone.
     *
     * @param scope the scope used if a zone lookup is required
     * @param domainNameProps the DomainNameProps objects to convert
     */
    static toZoneMapFromProps(scope: Construct, domainNameProps: DomainNameProps[]): {
        [domainName: string]: IHostedZone;
    };
    /**
     * Finds the domain name matching the given properties in an array of DomainName objects.
     *
     * @param props the properties to compare
     * @param domainNames the domain names to search
     * @return the matching domain name or undefined
     */
    static findDomainName(props: DomainNameProps, domainNames?: DomainName[]): DomainName | undefined;
}
